Credits
=======

This work is done based on the post of Thomas Sutton (https://passingcuriosity.com/2010/default-settings-for-django-applications/).

Development Lead
----------------

* Sigma Geosistemas LTDA <atendimento@sigmageosistemas.com.br>

Contributors
------------

George R. C. Silva